==> nextcloud-app-bookmarks-1%3a1.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/pl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Zakładki",
    "Add a Bookmark" : "Dodaj Zakładkę",
    "Add folder" : "Dodaj katalog",
    "Select" : "Wybierz",
    "Deselect" : "Odznacz",
    "Details" : "Szczegóły",
    "Delete" : "Usuń",
    "Saved" : "Zapisano",
    "Date added" : "Dodano datę",
    "Link" : "Link",
    "Tags" : "Etykiety",
    "Description" : "Opis",
    "No bookmarks here." : "Brak tutaj zakładek.",
    "Favorites" : "Ulubione",
    "Settings" : "Ustawienia",
    "Bookmarklet" : "Skryptozakładka",
    "Add to {instanceName} " : "Dodaj do {instanceName} ",
    "Recently added" : "Ostatnio dodane",
    "Most visited" : "Najczęściej odwiedzane",
    "View mode" : "Tryb podglądu",
    "List view" : "Widok listy",
    "RSS Feed" : "Kanał RSS",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Trwale usuń wszystkie zakładki ze swojego konta. Operacja nieodwracalna!",
    "Delete all bookmarks" : "Usuń wszystkie zakładki",
    "Open details" : "Otwórz szczegóły",
    "An error occurred while trying to save the bookmark." : "Wystąpił błąd podczas próby zapisania zakładki.",
    "Error" : "Błąd",
    "Uncategorized" : "Bez kategorii",
    "Error parsing the import result" : "Błąd podczas analizowania wyniku importu",
    "Import completed successfully." : "Importowanie zakończone pomyślnie.",
    "Do you really want to delete all your bookmarks?" : "Czy na pewno chcesz usunąć wszystkie swoje zakładki?",
    "Set tags" : "Ustaw etykiety",
    "Failed to import one bookmark, because: " : "Nie można było zaimportować jednej zakładki ponieważ:",
    "No file provided for import" : "Brak pliku do importu",
    "Unsupported file type for import" : "NIewspierany typ pliku importowania",
    "A Bookmark manager for Nextcloud" : "Menadżer zakładek dla Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Ta aplikacja umożliwia przechowywanie i organizowanie ulubionych miejsc w Internecie w jednym miejscu, jednocześnie umożliwiając ich synchronizację z różnymi urządzeniami i przeglądarkami. Sprawdź klientów wymienionych tutaj: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Dodaj zakładkę",
    "This URL is already bookmarked! Overwrite?" : "Ten URL jest już w zakładkach! Nadpisać?",
    "The title of the page" : "Tytuł strony",
    "The address of the page" : "Adres strony",
    "Description of the page" : "Opis strony",
    "Save" : "Zapisz",
    "Previews" : "Podglądy",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Aby wyświetlać prawdziwe zrzuty ekranu witryn z zakładek, aplikacja Zakładki może korzystać z usług stron trzecich w celu ich wygenerowania.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Możesz zarejestrować się za darmo na <a href=\"http://screeenly.com\">screeenly.com</a> lub <a href=\"https://github.com/stefanzweifel/screeenly\">skonfigurować własny serwer</a>.",
    "Screeenly API URL" : "URL API dla Screenly",
    "Screeenly API key" : "Klucz API dla Screenly",
    "Bookmarks feed" : "Kanał zakładek"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-app-bookmarks-1%3a2.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/pl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Zakładki",
    "Add a Bookmark" : "Dodaj Zakładkę",
    "Add folder" : "Dodaj katalog",
    "Select" : "Wybierz",
    "Deselect" : "Odznacz",
    "Details" : "Szczegóły",
    "Delete" : "Usuń",
    "Saved" : "Zapisano",
    "Date added" : "Dodano datę",
    "Link" : "Link",
    "Tags" : "Etykiety",
    "Description" : "Opis",
    "No bookmarks here." : "Brak tutaj zakładek.",
    "Favorites" : "Ulubione",
    "Settings" : "Ustawienia",
    "Bookmarklet" : "Skryptozakładka",
    "Add to {instanceName} " : "Dodaj do {instanceName} ",
    "Recently added" : "Ostatnio dodane",
    "Most visited" : "Najczęściej odwiedzane",
    "View mode" : "Tryb podglądu",
    "List view" : "Widok listy",
    "RSS Feed" : "Kanał RSS",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Trwale usuń wszystkie zakładki ze swojego konta. Operacja nieodwracalna!",
    "Delete all bookmarks" : "Usuń wszystkie zakładki",
    "Open details" : "Otwórz szczegóły",
    "An error occurred while trying to save the bookmark." : "Wystąpił błąd podczas próby zapisania zakładki.",
    "Error" : "Błąd",
    "Uncategorized" : "Bez kategorii",
    "Error parsing the import result" : "Błąd podczas analizowania wyniku importu",
    "Import completed successfully." : "Importowanie zakończone pomyślnie.",
    "Do you really want to delete all your bookmarks?" : "Czy na pewno chcesz usunąć wszystkie swoje zakładki?",
    "Set tags" : "Ustaw etykiety",
    "Not allowed to access folder to import into" : "Nie można uzyskać dostępu do katalogu, aby go zaimportować",
    "Failed to import one bookmark, because: " : "Nie można było zaimportować jednej zakładki ponieważ:",
    "No file provided for import" : "Brak pliku do importu",
    "Unsupported file type for import" : "NIewspierany typ pliku importowania",
    "A Bookmark manager for Nextcloud" : "Menadżer zakładek dla Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Ta aplikacja umożliwia przechowywanie i organizowanie ulubionych miejsc w Internecie w jednym miejscu, jednocześnie umożliwiając ich synchronizację z różnymi urządzeniami i przeglądarkami. Sprawdź klientów wymienionych tutaj: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Dodaj zakładkę",
    "This URL is already bookmarked! Overwrite?" : "Ten URL jest już w zakładkach! Nadpisać?",
    "The title of the page" : "Tytuł strony",
    "The address of the page" : "Adres strony",
    "Description of the page" : "Opis strony",
    "Save" : "Zapisz",
    "Previews" : "Podglądy",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Aby wyświetlać prawdziwe zrzuty ekranu witryn z zakładek, aplikacja Zakładki może korzystać z usług stron trzecich w celu ich wygenerowania.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Możesz zarejestrować się za darmo na <a href=\"http://screeenly.com\">screeenly.com</a> lub <a href=\"https://github.com/stefanzweifel/screeenly\">skonfigurować własny serwer</a>.",
    "Screeenly API URL" : "URL API dla Screenly",
    "Screeenly API key" : "Klucz API dla Screenly",
    "Bookmarks feed" : "Kanał zakładek"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
